@@ -260,7 +260,7 @@ impl<E: PairingEngine> VerifyingKey<E> {
 
 /// Full public (prover and verifier) parameters for the GM17 zkSNARK.
 #[derive(Clone, Debug, Eq)]
-pub struct Parameters<E: PairingEngine> {
+pub struct ProvingKey<E: PairingEngine> {
     pub vk: VerifyingKey<E>,
     pub a_query: Vec<E::G1Affine>,
     pub b_query: Vec<E::G2Affine>,
@@ -273,7 +273,7 @@ pub struct Parameters<E: PairingEngine> {
     pub g_gamma2_z_t: Vec<E::G1Affine>,
 }
 
-impl<E: PairingEngine> PartialEq for Parameters<E> {
+impl<E: PairingEngine> PartialEq for ProvingKey<E> {
     fn eq(&self, other: &Self) -> bool {
         self.vk == other.vk
             && self.a_query == other.a_query
@@ -288,32 +288,32 @@ impl<E: PairingEngine> PartialEq for Parameters<E> {
     }
 }
 
-impl<E: PairingEngine> ToBytes for Parameters<E> {
+impl<E: PairingEngine> ToBytes for ProvingKey<E> {
     fn write<W: Write>(&self, mut writer: W) -> IoResult<()> {
         self.write(&mut writer)
     }
 }
 
-impl<E: PairingEngine> FromBytes for Parameters<E> {
+impl<E: PairingEngine> FromBytes for ProvingKey<E> {
     #[inline]
     fn read<R: Read>(mut reader: R) -> IoResult<Self> {
         Self::read(&mut reader, false)
     }
 }
 
-impl<E: PairingEngine> From<Parameters<E>> for VerifyingKey<E> {
-    fn from(other: Parameters<E>) -> Self {
+impl<E: PairingEngine> From<ProvingKey<E>> for VerifyingKey<E> {
+    fn from(other: ProvingKey<E>) -> Self {
         other.vk
     }
 }
 
-impl<E: PairingEngine> From<Parameters<E>> for PreparedVerifyingKey<E> {
-    fn from(other: Parameters<E>) -> Self {
+impl<E: PairingEngine> From<ProvingKey<E>> for PreparedVerifyingKey<E> {
+    fn from(other: ProvingKey<E>) -> Self {
         prepare_verifying_key(other.vk)
     }
 }
 
-impl<E: PairingEngine> Parameters<E> {
+impl<E: PairingEngine> ProvingKey<E> {
     /// Serialize the parameters to bytes.
     pub fn write<W: Write>(&self, mut writer: W) -> IoResult<()> {
         self.vk.write(&mut writer)?;
@@ -497,7 +497,7 @@ impl<E: PairingEngine> ToBytes for PreparedVerifyingKey<E> {
 
 type AffinePair<'a, T> = (&'a [T], &'a [T]);
 
-impl<E: PairingEngine> Parameters<E> {
+impl<E: PairingEngine> ProvingKey<E> {
     pub fn get_vk(&self, _: usize) -> SynthesisResult<VerifyingKey<E>> {
         Ok(self.vk.clone())
     }
